@@ -205,6 +205,12 @@ class Expr(object):
     def between(self, start, end):
         return Between(self, start, end)
 
+    def concat(self, *args):
+        return Concat(self, *args)
+
+    def concat_ws(self, sep, *args):
+        return Concat(self, *args).ws(sep)
+
     def __getitem__(self, key):
         """Returns self.between()"""
         if isinstance(key, slice):
@@ -332,6 +338,29 @@ class ExprList(Expr):
         return params
 
 
+class Concat(ExprList):
+    def __init__(self, *args):
+        super(Concat, self).__init__(*args)
+        self._sep = ' || '
+        self._ws = None
+
+    def ws(self, sep):
+        self._ws = prepare_expr(sep)
+        return self
+
+    def __params__(self):
+        params = []
+        params.extend(sqlparams(self._ws))
+        params.extend(super(Concat, self).__params__())
+        return params
+
+    def __sqlrepr__(self, dialect):
+        value = super(Concat, self).__sqlrepr__(dialect)
+        if self._ws:
+            return "concat_ws({0}, {1})".format(self._ws, value)
+        return value
+
+
 class Placeholder(Expr):
     def __init__(self, *params):
         super(Placeholder, self).__init__(PLACEHOLDER, *params)
